!-----------------------BEGIN NOTICE -- DO NOT EDIT-----------------------
! NASA Goddard Space Flight Center Land Information System (LIS) v7.1
!
! Copyright (c) 2015 United States Government as represented by the
! Administrator of the National Aeronautics and Space Administration.
! All Rights Reserved.
!-------------------------END NOTICE -- DO NOT EDIT-----------------------
#include "LIS_misc.h"
!BOP
! 
! !DESCRIPTION: 
!   
! 
!  Reference: Getirana et al. (2012), "", Journal of Hydrometeorology. 
!
! !REVISION HISTORY: 
! 08 Nov 2011: Augusto Getirana, Initial implementation in LIS based on the 
!                                HYMAP offline routing code. 
! 
! !USES: 
subroutine HYMAP_routing_run(n)

  use ESMF
  use LIS_coreMod
  use LIS_fileIOMod
  use LIS_timeMgrMod
  use LIS_routingMod
  use LIS_logMod
  use LIS_historyMod
  use LIS_histDataMod
  use LIS_constantsMod
  use HYMAP_routingMod
#if(defined USE_NETCDF3 || defined USE_NETCDF4)
  use netcdf
#endif
  
  implicit none
  
  integer, intent(in)   :: n  
  integer               :: m
  type(ESMF_Field)      :: sf_runoff_field
  type(ESMF_Field)      :: baseflow_field
  real,   allocatable       :: surface_runoff(:,:)
  real,   pointer       :: surface_runoff_t(:)
  real,   pointer       :: baseflow_t(:)
  integer, allocatable      :: nqs(:,:)
  real,   allocatable       :: qs(:,:),qs_t(:)
  real,   allocatable       :: qsb(:,:),qsb_t(:)
  real,   allocatable       :: baseflow(:,:)
  real,   allocatable       :: rivsto_lvec(:)
  real,   allocatable       :: rivdph_lvec(:)
  real,   allocatable       :: rivvel_lvec(:)
  real,   allocatable       :: rivout_lvec(:)
  real,   allocatable       :: evpout_lvec(:)
  real,   allocatable       :: fldout_lvec(:)
  real,   allocatable       :: fldsto_lvec(:)
  real,   allocatable       :: flddph_lvec(:)
  real,   allocatable       :: fldvel_lvec(:)
  real,   allocatable       :: fldfrc_lvec(:)
  real,   allocatable       :: fldare_lvec(:)
  real,   allocatable       :: sfcelv_lvec(:)
  real,   allocatable       :: rnfsto_lvec(:)
  real,   allocatable       :: bsfsto_lvec(:)
  integer               :: status
  logical               :: check_Flag
  logical               :: alarmCheck
  integer               :: c,r,t
  character*100         :: filename
  logical               :: file_exists
  integer               :: ios, nid,qsid,qsbid

  alarmCheck = LIS_isAlarmRinging(LIS_rc, "HYMAP router model alarm")
  if(alarmCheck) then 

     allocate(rivsto_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(rivdph_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(rivvel_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(rivout_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(evpout_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(fldout_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(fldsto_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(flddph_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(fldvel_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(fldfrc_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(fldare_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(sfcelv_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(rnfsto_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     allocate(bsfsto_lvec(LIS_rc%npatch(n,LIS_rc%lsm_index)))
     
     if(HYMAP_routing_struc(n)%useens.eq.1) then 
        if(LIS_masterproc) then     
           !run the routing model at 1 hour output interval
           
           call ESMF_StateGet(LIS_runoff_state(n),"Surface Runoff",&
                sf_runoff_field,&
                rc=status)
           call LIS_verify(status, "ESMF_StateGet failed for Surface Runoff")
           
           call ESMF_StateGet(LIS_runoff_state(n),"Subsurface Runoff",&
                baseflow_field, rc=status)
           call LIS_verify(status, "ESMF_StateGet failed for Subsurface Runoff")
           
           call ESMF_FieldGet(sf_runoff_field,localDE=0,&
                farrayPtr=surface_runoff_t,&
                rc=status)
           call LIS_verify(status, "ESMF_FieldGet failed for Surface Runoff")
           
           call ESMF_FieldGet(baseflow_field,localDE=0,farrayPtr=baseflow_t,&
                rc=status)
           call LIS_verify(status, "ESMF_FieldGet failed for Subsurface Runoff")
           
           allocate(surface_runoff(LIS_rc%gnc(n),LIS_rc%gnr(n)))
           allocate(baseflow(LIS_rc%gnc(n),LIS_rc%gnr(n)))           

           do m=1,LIS_rc%nensem(n)
              
              surface_runoff = 0.0
              baseflow = 0.0

              call LIS_tile2grid(n,m,surface_runoff,surface_runoff_t)
              call LIS_tile2grid(n,m,baseflow,baseflow_t)
              
              call model(LIS_rc%udef,&
                   LIS_rc%gnc(n),&
                   LIS_rc%gnr(n),&				   
                   HYMAP_routing_struc(n)%inz,&
                   nint(HYMAP_routing_struc(n)%dt),&
                   HYMAP_routing_struc(n)%flowtype,&
                   HYMAP_routing_struc(n)%linresflag,&
                   HYMAP_routing_struc(n)%evapflag,&
                   HYMAP_routing_struc(n)%seqx,&
                   HYMAP_routing_struc(n)%seqy,&
                   HYMAP_routing_struc(n)%nseqriv,&
                   HYMAP_routing_struc(n)%nseqall,&		   
                   HYMAP_routing_struc(n)%nextx,&
                   HYMAP_routing_struc(n)%nexty,&
                   HYMAP_routing_struc(n)%elevtn,&
                   HYMAP_routing_struc(n)%nxtdst,&
                   HYMAP_routing_struc(n)%grarea,&	   
                   HYMAP_routing_struc(n)%fldgrd,&
                   HYMAP_routing_struc(n)%fldman,&
                   HYMAP_routing_struc(n)%fldstomax,&
                   HYMAP_routing_struc(n)%rivman,&
                   HYMAP_routing_struc(n)%rivelv,&
                   HYMAP_routing_struc(n)%rivstomax,&
                   HYMAP_routing_struc(n)%rivlen,&
                   HYMAP_routing_struc(n)%rivwth,&
                   HYMAP_routing_struc(n)%rivhgt,&
                   HYMAP_routing_struc(n)%rivare,&
                   HYMAP_routing_struc(n)%rslpmin,&
                   HYMAP_routing_struc(n)%trnoff,&
                   HYMAP_routing_struc(n)%tbsflw,&
                   HYMAP_routing_struc(n)%cntime,&
                   HYMAP_routing_struc(n)%mask,&
                   surface_runoff,&
                   baseflow,&
                   
                   !==== TEMPORARILY COMMENTED ====
                   !input evap        
                   !HYMAP_routing_struc(n)%tsfc,&
                   !HYMAP_routing_struc(n)%psur,&
                   !HYMAP_routing_struc(n)%pres,&
                   !HYMAP_routing_struc(n)%tair,&
                   !HYMAP_routing_struc(n)%relh,&
                   !HYMAP_routing_struc(n)%wind,&
                   !HYMAP_routing_struc(n)%zref,&
                   
                   !outputs
                   HYMAP_routing_struc(n)%rivsto(:,:,m),&
                   HYMAP_routing_struc(n)%rivdph(:,:,m),&
                   HYMAP_routing_struc(n)%rivvel(:,:,m),&
                   HYMAP_routing_struc(n)%rivout(:,:,m),&
                   HYMAP_routing_struc(n)%evpout(:,:,m),&
                   HYMAP_routing_struc(n)%fldout(:,:,m),&
                   HYMAP_routing_struc(n)%fldsto(:,:,m),&
                   HYMAP_routing_struc(n)%flddph(:,:,m),&
                   HYMAP_routing_struc(n)%fldvel(:,:,m),&
                   HYMAP_routing_struc(n)%fldfrc(:,:,m),&
                   HYMAP_routing_struc(n)%fldare(:,:,m),&
                   HYMAP_routing_struc(n)%sfcelv(:,:,m),&
                   HYMAP_routing_struc(n)%rnfsto(:,:,m),&
                   HYMAP_routing_struc(n)%bsfsto(:,:,m))

!========================================================================			
! the following is done to distribute the global arrays to the individual 
! processors, so that they can use the generic LIS interfaces for writing
! output -- which works based on the assumption of multiprocessors. 
! When the HYMAP routine itself is parallelized, this can (should) be taken
! out. 

        
           enddo
           deallocate(surface_runoff)
           deallocate(baseflow)
        endif

        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%rivsto,&
             rivsto_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%rivdph,&
             rivdph_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%rivvel,&
             rivvel_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%rivout,&
             rivout_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%evpout,&
             evpout_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%fldout,&
             fldout_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%fldsto,&
             fldsto_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%flddph,&
             flddph_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%fldvel,&
             fldvel_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%fldfrc,&
             fldfrc_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%fldare,&
             fldare_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%sfcelv,&
             sfcelv_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%rnfsto,&
             rnfsto_lvec,1)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%bsfsto,&
             bsfsto_lvec,1)
        
        do t=1, LIS_rc%npatch(n,LIS_rc%lsm_index)
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_RIVSTO,&
                value=rivsto_lvec(t),vlevel=1,unit="m3",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_RIVDPH,&
                value=rivdph_lvec(t),vlevel=1,unit="m",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_RIVVEL,&
                value=rivvel_lvec(t),vlevel=1,unit="m/s",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_STREAMFLOW,&
                value=rivout_lvec(t),vlevel=1,unit="m3/s",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDEVAP,&
                value=evpout_lvec(t),vlevel=1,unit="m3",&   
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDOUT,&
                value=fldout_lvec(t),vlevel=1,unit="m3/s",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDSTO,&
                value=fldsto_lvec(t),vlevel=1,unit="m3",&
                direction="-")
              
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDDPH,&
                value=flddph_lvec(t),vlevel=1,unit="m",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDVEL,&
                value=fldvel_lvec(t),vlevel=1,unit="m/s",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDFRC,&
                value=fldfrc_lvec(t),vlevel=1,unit="-",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDARE,&
                value=fldare_lvec(t),vlevel=1,unit="m2",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_SFCELV,&
                value=sfcelv_lvec(t),vlevel=1,unit="m",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_RNFSTO,&
                value=rnfsto_lvec(t),vlevel=1,unit="m3",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_BSFSTO,&
                value=bsfsto_lvec(t),vlevel=1,unit="m3",&
                direction="-")
           
        enddo
     else
        if(LIS_masterproc) then     
           if(LIS_rc%lsm.ne."none") then 
              
              call ESMF_StateGet(LIS_runoff_state(n),"Surface Runoff",sf_runoff_field,&
                   rc=status)
              call LIS_verify(status, "ESMF_StateGet failed for Surface Runoff")
              
              call ESMF_StateGet(LIS_runoff_state(n),"Subsurface Runoff",&
                   baseflow_field, rc=status)
              call LIS_verify(status, "ESMF_StateGet failed for Subsurface Runoff")
              
              call ESMF_FieldGet(sf_runoff_field,localDE=0,farrayPtr=surface_runoff_t,&
                   rc=status)
              call LIS_verify(status, "ESMF_FieldGet failed for Surface Runoff")
              
              call ESMF_FieldGet(baseflow_field,localDE=0,farrayPtr=baseflow_t,&
                   rc=status)
              call LIS_verify(status, "ESMF_FieldGet failed for Subsurface Runoff")
                         
              allocate(surface_runoff(LIS_rc%gnc(n),LIS_rc%gnr(n)))
              allocate(baseflow(LIS_rc%gnc(n),LIS_rc%gnr(n)))
              
              call LIS_tile2grid(n,surface_runoff,surface_runoff_t,1)
              call LIS_tile2grid(n,baseflow,baseflow_t,1)
              
           else !read from previous output. 
              !caveats 
              ! 1) assumes the LIS outputs are the same output interval as that of
              ! the HYMAP model timestep. No temporal aggregation is done. 
              !
              ! 3) Assumes that the units of Qs and Qsb are in kg/m2s
              !
              ! 4) Assumes that the LIS outputs are in the same grid/map projection/
              ! resolution.
              ! 
              ! 5) LIS outputs are in NETCDF format. 
              !
              
              allocate(surface_runoff(LIS_rc%gnc(n),LIS_rc%gnr(n)))
              allocate(baseflow(LIS_rc%gnc(n),LIS_rc%gnr(n)))
              
           !create LIS filename
              call LIS_create_output_filename(n, &
                   filename, check_flag, &
                   model_name='SURFACEMODEL', &
                   odir=HYMAP_routing_struc(n)%LISdir,&
                   writeint=HYMAP_routing_struc(n)%outInterval)
              
#if (defined USE_NETCDF3 || defined USE_NETCDF4)
              
              inquire(file=filename, exist=file_exists)
              if(file_exists) then 
                 write(LIS_logunit,*) 'Reading '//trim(filename)
                 allocate(qs(LIS_rc%gnc(n),LIS_rc%gnr(n)))
                 allocate(qsb(LIS_rc%gnc(n),LIS_rc%gnr(n)))
                 
                 ios = nf90_open(path=filename,&
                      mode=NF90_NOWRITE,ncid=nid)
                 call LIS_verify(ios,'Error in HYMAP_routing_run')
                 
                 ios = nf90_inq_varid(nid,'Qs_tavg',qsid)
                 call LIS_verify(ios,'failed to read Qs_tavg field in HYMAP_routing_run')
                 
                 ios = nf90_inq_varid(nid,'Qsb_tavg',qsbid)
                 call LIS_verify(ios,'failed to read Qsb_tavg field in HYMAP_routing_run')
                 
                 if(LIS_rc%wopt.eq."2d gridspace") then 
                    ios = nf90_get_var(nid,qsid,qs)
                    call LIS_verify(ios, 'failed to read Qs_tavg field in HYMAP_routing_run')
                    
                    ios = nf90_get_var(nid,qsbid,qsb)
                    call LIS_verify(ios, 'failed to read Qsb_tavg field in HYMAP_routing_run')
                 elseif(LIS_rc%wopt.eq."1d tilespace") then 
                    
                    allocate(qs_t(LIS_rc%glbntiles(n)))
                    allocate(qsb_t(LIS_rc%glbntiles(n)))
                    allocate(nqs(LIS_rc%gnc(n),LIS_rc%gnr(n)))
                    
                    ios = nf90_get_var(nid,qsid,qs_t)
                    call LIS_verify(ios, 'failed to read Qs_tavg field in HYMAP_routing_run')
                    
                    ios = nf90_get_var(nid,qsbid,qsb_t)
                    call LIS_verify(ios, 'failed to read Qsb_tavg field in HYMAP_routing_run')
                    
                    do t=1,LIS_rc%glbntiles(n)
                       c = LIS_domain(n)%tile(t)%col
                       r = LIS_domain(n)%tile(t)%row
                       
                       qs(c,r) = qs(c,r) + qs_t(t)
                       qsb(c,r) = qsb(c,r) + qsb_t(t)
                       nqs(c,r) = nqs(c,r) + 1
                    enddo
                    
                    do r=1,LIS_rc%gnr(n)
                       do c=1,LIS_rc%gnc(n)
                          if(nqs(c,r).gt.0) then 
                             qs(c,r) = qs(c,r)/nqs(c,r)
                             qsb(c,r) = qsb(c,r)/nqs(c,r)
                          else
                             qs(c,r) = LIS_rc%udef
                             qsb(c,r) = LIS_rc%udef
                          endif
                       enddo
                    enddo
                    deallocate(qs_t)
                    deallocate(qsb_t)
                    deallocate(nqs)
                 endif
                 
                 do r=1,LIS_rc%gnr(n)
                    do c=1,LIS_rc%gnc(n)
                       if(qs(c,r).ne.-9999.0) then 
!                          surface_runoff(c,r) = qs(c,r)/(LIS_CONST_RHOFW)
!                          baseflow(c,r) = qsb(c,r)/(LIS_CONST_RHOFW)
                          surface_runoff(c,r) = qs(c,r)
                          baseflow(c,r) = qsb(c,r)
                       else
                          surface_runoff(c,r) = 0.0
                          baseflow(c,r) = 0.0
                       endif
                    enddo
                 enddo
                 
                 deallocate(qs)
                 deallocate(qsb)
                 call LIS_verify(nf90_close(nid))
              else
                 write(LIS_logunit,*) 'Failed to find '//trim(filename)
                 call LIS_endrun()
              endif
#endif
           endif

           call model(LIS_rc%udef,&
                LIS_rc%gnc(n),&
                LIS_rc%gnr(n),&				   
                HYMAP_routing_struc(n)%inz,&
                nint(HYMAP_routing_struc(n)%dt),&
                HYMAP_routing_struc(n)%flowtype,&
                HYMAP_routing_struc(n)%linresflag,&
                HYMAP_routing_struc(n)%evapflag,&
                HYMAP_routing_struc(n)%seqx,&
                HYMAP_routing_struc(n)%seqy,&
                HYMAP_routing_struc(n)%nseqriv,&
                HYMAP_routing_struc(n)%nseqall,&		   
                HYMAP_routing_struc(n)%nextx,&
                HYMAP_routing_struc(n)%nexty,&
                HYMAP_routing_struc(n)%elevtn,&
                HYMAP_routing_struc(n)%nxtdst,&
                HYMAP_routing_struc(n)%grarea,&	   
                HYMAP_routing_struc(n)%fldgrd,&
                HYMAP_routing_struc(n)%fldman,&
                HYMAP_routing_struc(n)%fldstomax,&
                HYMAP_routing_struc(n)%rivman,&
                HYMAP_routing_struc(n)%rivelv,&
                HYMAP_routing_struc(n)%rivstomax,&
                HYMAP_routing_struc(n)%rivlen,&
                HYMAP_routing_struc(n)%rivwth,&
                HYMAP_routing_struc(n)%rivhgt,&
                HYMAP_routing_struc(n)%rivare,&
                HYMAP_routing_struc(n)%rslpmin,&
                HYMAP_routing_struc(n)%trnoff,&
                HYMAP_routing_struc(n)%tbsflw,&
                HYMAP_routing_struc(n)%cntime,&
                HYMAP_routing_struc(n)%mask,&
                surface_runoff,&
                baseflow,&
                   
                   !==== TEMPORARILY COMMENTED ====
                   !input evap        
                   !HYMAP_routing_struc(n)%tsfc,&
                   !HYMAP_routing_struc(n)%psur,&
                   !HYMAP_routing_struc(n)%pres,&
                   !HYMAP_routing_struc(n)%tair,&
                   !HYMAP_routing_struc(n)%relh,&
                   !HYMAP_routing_struc(n)%wind,&
                   !HYMAP_routing_struc(n)%zref,&
                   
                   !outputs
                HYMAP_routing_struc(n)%rivsto,&
                HYMAP_routing_struc(n)%rivdph,&
                HYMAP_routing_struc(n)%rivvel,&
                HYMAP_routing_struc(n)%rivout,&
                HYMAP_routing_struc(n)%evpout,&
                HYMAP_routing_struc(n)%fldout,&
                HYMAP_routing_struc(n)%fldsto,&
                HYMAP_routing_struc(n)%flddph,&
                HYMAP_routing_struc(n)%fldvel,&
                HYMAP_routing_struc(n)%fldfrc,&
                HYMAP_routing_struc(n)%fldare,&
                HYMAP_routing_struc(n)%sfcelv,&
                HYMAP_routing_struc(n)%rnfsto,&
                HYMAP_routing_struc(n)%bsfsto)

!========================================================================			
! the following is done to distribute the global arrays to the individual 
! processors, so that they can use the generic LIS interfaces for writing
! output -- which works based on the assumption of multiprocessors. 
! When the HYMAP routine itself is parallelized, this can (should) be taken
! out. 

        
           deallocate(surface_runoff)
           deallocate(baseflow)
        endif
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%rivsto(:,:,1),&
             rivsto_lvec)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%rivdph(:,:,1),&
             rivdph_lvec)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%rivvel(:,:,1),&
             rivvel_lvec)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%rivout(:,:,1),&
             rivout_lvec)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%evpout(:,:,1),&
             evpout_lvec)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%fldout(:,:,1),&
             fldout_lvec)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%fldsto(:,:,1),&
             fldsto_lvec)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%flddph(:,:,1),&
             flddph_lvec)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%fldvel(:,:,1),&
             fldvel_lvec)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%fldfrc(:,:,1),&
             fldfrc_lvec)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%fldare(:,:,1),&
             fldare_lvec)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%sfcelv(:,:,1),&
             sfcelv_lvec)
        
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%rnfsto(:,:,1),&
             rnfsto_lvec)
	
        call LIS_grid2patch(n,LIS_rc%lsm_index,HYMAP_routing_struc(n)%bsfsto(:,:,1),&
             bsfsto_lvec)
        
        do t=1, LIS_rc%npatch(n,LIS_rc%lsm_index)
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_RIVSTO,&
                value=rivsto_lvec(t),vlevel=1,unit="m3",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_RIVDPH,&
                value=rivdph_lvec(t),vlevel=1,unit="m",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_RIVVEL,&
                value=rivvel_lvec(t),vlevel=1,unit="m/s",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_STREAMFLOW,&
                value=rivout_lvec(t),vlevel=1,unit="m3/s",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDEVAP,&
                value=evpout_lvec(t),vlevel=1,unit="m3",&   
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDOUT,&
                value=fldout_lvec(t),vlevel=1,unit="m3/s",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDSTO,&
                value=fldsto_lvec(t),vlevel=1,unit="m3",&
                direction="-")

           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDDPH,&
                value=flddph_lvec(t),vlevel=1,unit="m",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDVEL,&
                value=fldvel_lvec(t),vlevel=1,unit="m/s",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDFRC,&
                value=fldfrc_lvec(t),vlevel=1,unit="-",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_FLDARE,&
                value=fldare_lvec(t),vlevel=1,unit="m2",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_SFCELV,&
                value=sfcelv_lvec(t),vlevel=1,unit="m",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_RNFSTO,&
                value=rnfsto_lvec(t),vlevel=1,unit="m3",&
                direction="-")
           
           call LIS_diagnoseRoutingOutputVar(n, t,LIS_MOC_BSFSTO,&
                value=bsfsto_lvec(t),vlevel=1,unit="m3",&
                direction="-")
           
        enddo
                
     endif
     deallocate(rivsto_lvec)
     deallocate(rivdph_lvec)
     deallocate(rivvel_lvec)
     deallocate(rivout_lvec)
     deallocate(evpout_lvec)
     deallocate(fldout_lvec)
     deallocate(fldsto_lvec)
     deallocate(flddph_lvec)
     deallocate(fldvel_lvec)
     deallocate(fldfrc_lvec)
     deallocate(fldare_lvec)
     deallocate(sfcelv_lvec)
     deallocate(rnfsto_lvec)
     deallocate(bsfsto_lvec)
     
  endif
end subroutine HYMAP_routing_run
